@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Client.pm 77 2006-11-30 23:10:18Z miyagawa $
 
 package XML::Atom::Client;
 use strict;
@@ -13,7 +13,6 @@ use Digest::SHA1 qw( sha1 );
 use MIME::Base64 qw( encode_base64 );
 use DateTime;
 
-use constant NS_ATOM => 'http://purl.org/atom/ns#';
 use constant NS_SOAP => 'http://schemas.xmlsoap.org/soap/envelope/';
 
 sub new {
@@ -28,6 +27,7 @@ sub init {
     my %param = @_;
     $client->{ua} = LWP::UserAgent::AtomClient->new($client);
     $client->{ua}->agent('XML::Atom/' . XML::Atom->VERSION);
+    $client->{ua}->parse_head(0);
     $client;
 }
 
@@ -218,6 +218,7 @@ sub _utf8_off {
 
 package LWP::UserAgent::AtomClient;
 use strict;
+use Scalar::Util;
 
 use base qw( LWP::UserAgent );
 
@@ -226,6 +227,7 @@ sub new {
     my($class, $client) = @_;
     my $ua = $class->SUPER::new;
     $ClientOf{$ua} = $client;
+    Scalar::Util::weaken($ClientOf{$ua});
     $ua;
 }
 
